<?php
/**
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * $Horde: jonah/channels/index.php,v 1.40 2007/01/02 12:48:19 jan Exp $
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 * @author Marko Djukic <marko@oblo.com>
 */

@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';

if (!Jonah::checkPermissions('jonah:news', PERMS_EDIT)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

$have_news = Jonah_News::getAvailableTypes();
if (empty($have_news)) {
    $notification->push(_("News is not enabled."), 'horde.warning');
    $url = Horde::applicationUrl('index.php', true);
    header('Location: ' . $url);
    exit;
}

$news = Jonah_News::factory();

$channels = $news->getChannels(array_keys($have_news));
if (is_a($channels, 'PEAR_Error')) {
    $notification->push(sprintf(_("An error occurred fetching channels: %s"), $channels->getMessage()), 'horde.error');
    $channels = false;
} elseif ($channels) {
    $channels = Jonah::checkPermissions('channels', PERMS_SHOW, $channels);
    /* Build channel specific fields. */
    foreach ($channels as $key => $channel) {
        /* Edit channel link. */
        $url = Horde::applicationUrl('channels/edit.php');
        $url = Util::addParameter($url, 'channel_id', $channel['channel_id']);
        $channels[$key]['edit_link'] = Horde::link($url, _("Edit channel"), '', '', '', _("Edit channel")) . Horde::img('edit.png', _("Edit channel"), '', $registry->getImageDir('horde')) . '</a>';

        /* Delete channel link. */
        $url = Horde::applicationUrl('channels/delete.php');
        $url = Util::addParameter($url, 'channel_id', $channel['channel_id']);
        $channels[$key]['delete_link'] = Horde::link($url, _("Delete channel"), '', '', '', _("Delete channel")) . Horde::img('delete.png', _("Delete channel"), null, $registry->getImageDir('horde')) . '</a>';

        /* View stories link. */
        $url = Horde::applicationUrl('stories/index.php');
        $url = Util::addParameter($url, 'channel_id', $channel['channel_id']);
        $channels[$key]['stories_url'] = $url;

        /* List recipients for delivery of this channel. */
        $url = Horde::applicationUrl('lists/index.php');
        $url = Util::addParameter($url, 'channel_id', $channel['channel_id']);
        $channels[$key]['lists_url'] = $url;
        $channels[$key]['lists_link'] = Horde::link($url, _("Delivery lists"), '', '', '', _("Delivery lists")) . Horde::img('lists.png', _("Delivery lists")) . '</a>';

        /* Channel type specific links. */
        $channels[$key]['addstory_link'] = '';
        $channels[$key]['refresh_link'] = '';

        switch ($channel['channel_type']) {
        case JONAH_INTERNAL_CHANNEL:
            /* Add story link. */
            $url = Horde::applicationUrl('stories/edit.php');
            $url = Util::addParameter($url, 'channel_id', $channel['channel_id']);
            $channels[$key]['addstory_link'] = Horde::link($url, _("Add story"), '', '', '', _("Add story")) . Horde::img('new.png', _("Add story")) . '</a>';
            break;

        case JONAH_EXTERNAL_CHANNEL:
        case JONAH_AGGREGATED_CHANNEL:
            /* Refresh cache link. */
            $url = Horde::applicationUrl('stories/index.php');
            $url = Util::addParameter($url, array('channel_id' => $channel['channel_id'], 'refresh' => '1', 'url' => Horde::selfUrl()));
            $channels[$key]['refresh_link'] = Horde::link($url, _("Refresh channel"), '', '', '', _("Refresh channel")) . Horde::img('reload.png', _("Refresh channel"), '', $registry->getImageDir('horde')) . '</a>';
            break;
        }

        $channels[$key]['channel_type'] = Jonah::getChannelTypeLabel($channel['channel_type']);
        /* TODO: pref setting for date display. */
        $channels[$key]['channel_updated'] = ($channel['channel_updated'] ? date('M d, Y H:i', (int)$channel['channel_updated']) : '-');
    }
}

$template = new Horde_Template();
$template->set('header', _("Manage Feeds"));
$template->set('listheaders', array(_("Name"), _("Type"), _("Last Update")));
$template->set('channels', $channels, true);
$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

$title = _("Feeds");
require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/channels/index.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
